library config_jsonp_loader;

import 'dart:html';
import 'dart:async';
import 'dart:uri';
import '../config.dart';
import 'package:js/js.dart' as js;

class ConfigJsonpLoader extends ConfigLoader {
  var _completer = new Completer<String>();

  /**
   * A config loader will load the path from this script's host.
   */
  Future<String> loadConfig(String path) {

    var errorHandler = (error) => _completer.completeError(error);

    var scripthost = _getScriptHost();
    js.context.getconf = new js.Callback.once(getconf);
    var configurl = "";
    if (path.contains("?")) {
      configurl = "$scripthost/$path&callback=getconf";
    }
    else {
      configurl = "$scripthost/$path?callback=getconf";
    }
    print(configurl);
    var script = new ScriptElement()..src = configurl;
    script.type="application/json";
    document.head.nodes.add(script);

    return _completer.future;
  }

  String _getScriptHost() {
    var src = null;
    var scripts = queryAll("script");
    for (ScriptElement se in scripts) {
      if (se.type == "application/dart") {
        src = se.src;
        break;
      }
      else if (se.src.contains(".dart.js")) {
        src = se.src;
        break;
      }
    }

    if (src != null) {
      var uri = Uri.parse(src);
      return uri.origin;
    }
    else {
      throw "Could not get Dart script host";
    }
  }

  getconf(var data) {
    print(data);
    var results = data.results;
    _completer.complete(results);
  }

}

